@@ -8,13 +8,18 @@ from django.utils.functional import LazyObject
 from pipeline.conf import settings
 
 
-class CompressStorage(FileSystemStorage):
+class PipelineStorage(FileSystemStorage):
     def __init__(self, location=None, base_url=None, *args, **kwargs):
         if location is None:
             location = settings.PIPELINE_ROOT
         if base_url is None:
             base_url = settings.PIPELINE_URL
-        super(CompressStorage, self).__init__(location, base_url, *args, **kwargs)
+        super(PipelineStorage, self).__init__(location, base_url, *args, **kwargs)
+
+    def get_available_name(self, name):
+        if self.exists(name):
+            self.delete(name)
+        return name
 
     def accessed_time(self, name):
         return datetime.fromtimestamp(os.path.getatime(self.path(name)))
